// Copyright 2000-2024 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.platform.core.nio.fs;

import java.nio.file.CopyOption;
import java.nio.file.Path;
import java.nio.file.spi.FileSystemProvider;

/**
 * A mix-in interface for {@link FileSystemProvider}, which is checked by {@link MultiRoutingFileSystemProvider}.
 */
public interface RoutingAwareFileSystemProvider {
  /**
   * @return true if this file system provider can handle paths generated by other file system providers.
   * For example, such filesystems are able to handle {@link FileSystemProvider#copy(Path, Path, CopyOption...)} with paths from
   * two different file systems.
   */
  boolean canHandleRouting();
}
